import { __decorate, __awaiter } from 'tslib';
import { EventEmitter, ɵɵdefineInjectable, Injectable, NgModule } from '@angular/core';
import { timer, defer } from 'rxjs';
import { CommonsSynchronised } from 'tscommons-async';
import { CommonModule } from '@angular/common';

let CommonsSyncIntervalService = class CommonsSyncIntervalService {
    constructor() {
        this.intervals = new Map();
    }
    add(id, interval, paused = false) {
        if (this.intervals.has(id))
            return false;
        const subscription = timer(interval, interval)
            .subscribe(() => {
            const i = this.intervals.get(id);
            if (i === undefined)
                return;
            if (i.isPaused)
                return;
            i.emitter.emit(i.tally);
            i.tally++;
        });
        this.intervals.set(id, {
            emitter: new EventEmitter(true),
            tally: 0,
            subscription: subscription,
            isPaused: paused
        });
        return true;
    }
    intervalListener(id) {
        const interval = this.intervals.get(id);
        if (interval === undefined)
            return undefined;
        return interval.emitter;
    }
    pause(id) {
        const interval = this.intervals.get(id);
        if (interval === undefined)
            return false;
        interval.isPaused = true;
        return true;
    }
    resume(id) {
        const interval = this.intervals.get(id);
        if (interval === undefined)
            return false;
        interval.isPaused = false;
        return true;
    }
    remove(id) {
        const interval = this.intervals.get(id);
        if (interval === undefined)
            return false;
        interval.subscription.unsubscribe();
        this.intervals.delete(id);
        return true;
    }
};
CommonsSyncIntervalService.ɵprov = ɵɵdefineInjectable({ factory: function CommonsSyncIntervalService_Factory() { return new CommonsSyncIntervalService(); }, token: CommonsSyncIntervalService, providedIn: "root" });
CommonsSyncIntervalService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], CommonsSyncIntervalService);

let CommonsSynchronisedService = class CommonsSynchronisedService {
    constructor() {
        this.synchroniser = new CommonsSynchronised();
    }
    synchronised(context, timeout, timeoutAction, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.synchroniser.synchronised(context, timeout, timeoutAction, callback);
        });
    }
    synchronisedAsObservable(context, timeout, timeoutAction, callback) {
        return defer(() => __awaiter(this, void 0, void 0, function* () {
            return yield this.synchronised(context, timeout, timeoutAction, callback);
        }));
    }
};
CommonsSynchronisedService.ɵprov = ɵɵdefineInjectable({ factory: function CommonsSynchronisedService_Factory() { return new CommonsSynchronisedService(); }, token: CommonsSynchronisedService, providedIn: "root" });
CommonsSynchronisedService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], CommonsSynchronisedService);

var NgxAngularCommonsAsyncModule_1;
let NgxAngularCommonsAsyncModule = NgxAngularCommonsAsyncModule_1 = class NgxAngularCommonsAsyncModule {
    static forRoot() {
        return {
            ngModule: NgxAngularCommonsAsyncModule_1,
            providers: [
                CommonsSyncIntervalService,
                CommonsSynchronisedService
            ]
        };
    }
};
NgxAngularCommonsAsyncModule = NgxAngularCommonsAsyncModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule
        ],
        declarations: [],
        exports: []
    })
], NgxAngularCommonsAsyncModule);

/*
 * Public API Surface of ngx-angularcommons-async
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CommonsSyncIntervalService, CommonsSynchronisedService, NgxAngularCommonsAsyncModule };
//# sourceMappingURL=ngx-angularcommons-async.js.map
