import { __decorate, __awaiter, __generator } from 'tslib';
import { EventEmitter, ɵɵdefineInjectable, Injectable, NgModule } from '@angular/core';
import { timer, defer } from 'rxjs';
import { CommonsSynchronised } from 'tscommons-async';
import { CommonModule } from '@angular/common';

var CommonsSyncIntervalService = /** @class */ (function () {
    function CommonsSyncIntervalService() {
        this.intervals = new Map();
    }
    CommonsSyncIntervalService.prototype.add = function (id, interval, paused) {
        var _this = this;
        if (paused === void 0) { paused = false; }
        if (this.intervals.has(id))
            return false;
        var subscription = timer(interval, interval)
            .subscribe(function () {
            var i = _this.intervals.get(id);
            if (i === undefined)
                return;
            if (i.isPaused)
                return;
            i.emitter.emit(i.tally);
            i.tally++;
        });
        this.intervals.set(id, {
            emitter: new EventEmitter(true),
            tally: 0,
            subscription: subscription,
            isPaused: paused
        });
        return true;
    };
    CommonsSyncIntervalService.prototype.intervalListener = function (id) {
        var interval = this.intervals.get(id);
        if (interval === undefined)
            return undefined;
        return interval.emitter;
    };
    CommonsSyncIntervalService.prototype.pause = function (id) {
        var interval = this.intervals.get(id);
        if (interval === undefined)
            return false;
        interval.isPaused = true;
        return true;
    };
    CommonsSyncIntervalService.prototype.resume = function (id) {
        var interval = this.intervals.get(id);
        if (interval === undefined)
            return false;
        interval.isPaused = false;
        return true;
    };
    CommonsSyncIntervalService.prototype.remove = function (id) {
        var interval = this.intervals.get(id);
        if (interval === undefined)
            return false;
        interval.subscription.unsubscribe();
        this.intervals.delete(id);
        return true;
    };
    CommonsSyncIntervalService.ɵprov = ɵɵdefineInjectable({ factory: function CommonsSyncIntervalService_Factory() { return new CommonsSyncIntervalService(); }, token: CommonsSyncIntervalService, providedIn: "root" });
    CommonsSyncIntervalService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], CommonsSyncIntervalService);
    return CommonsSyncIntervalService;
}());

var CommonsSynchronisedService = /** @class */ (function () {
    function CommonsSynchronisedService() {
        this.synchroniser = new CommonsSynchronised();
    }
    CommonsSynchronisedService.prototype.synchronised = function (context, timeout, timeoutAction, callback) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.synchroniser.synchronised(context, timeout, timeoutAction, callback)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    CommonsSynchronisedService.prototype.synchronisedAsObservable = function (context, timeout, timeoutAction, callback) {
        var _this = this;
        return defer(function () { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.synchronised(context, timeout, timeoutAction, callback)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        }); });
    };
    CommonsSynchronisedService.ɵprov = ɵɵdefineInjectable({ factory: function CommonsSynchronisedService_Factory() { return new CommonsSynchronisedService(); }, token: CommonsSynchronisedService, providedIn: "root" });
    CommonsSynchronisedService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], CommonsSynchronisedService);
    return CommonsSynchronisedService;
}());

var NgxAngularCommonsAsyncModule = /** @class */ (function () {
    function NgxAngularCommonsAsyncModule() {
    }
    NgxAngularCommonsAsyncModule_1 = NgxAngularCommonsAsyncModule;
    NgxAngularCommonsAsyncModule.forRoot = function () {
        return {
            ngModule: NgxAngularCommonsAsyncModule_1,
            providers: [
                CommonsSyncIntervalService,
                CommonsSynchronisedService
            ]
        };
    };
    var NgxAngularCommonsAsyncModule_1;
    NgxAngularCommonsAsyncModule = NgxAngularCommonsAsyncModule_1 = __decorate([
        NgModule({
            imports: [
                CommonModule
            ],
            declarations: [],
            exports: []
        })
    ], NgxAngularCommonsAsyncModule);
    return NgxAngularCommonsAsyncModule;
}());

/*
 * Public API Surface of ngx-angularcommons-async
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CommonsSyncIntervalService, CommonsSynchronisedService, NgxAngularCommonsAsyncModule };
//# sourceMappingURL=ngx-angularcommons-async.js.map
